==> memsource-cli-3.3.323.tgz: package/lib/utils.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var fs = require('fs');

var axios = require('axios');

var findConfig = require('find-config');

var path = require('path');

var glob = require('glob');

var util = require('util');

var writeJsonFile = require('write-json-file');

var fromPairs = require('lodash.frompairs');

var writeFileAsync = util.promisify(fs.writeFile);
var mkdirp = util.promisify(require('mkdirp'));

var _require$setup = require('@cloudflare/cli-helpers').setup({
  cliName: 'memsource-cli'
}),
    bail = _require$setup.bail;

var config = findConfig.require('memsource.config.js');

var MEMSOURCE_USER = config.MEMSOURCE_USER,
    MEMSOURCE_PASS = config.MEMSOURCE_PASS;
var readdirSync = fs.readdirSync,
    statSync = fs.statSync;
/*
 * Constants
 */

var baseUrl = 'https://cloud.memsource.com/web/api2/v1/';
var dashPkgName = '@cloudflare/app-dash';
var CATALOGS_ROOT = '@cloudflare/intl-translations';
var validStatus = 'DELIVERED';
var localeMap = {
  de_de: 'de-DE'
};
var outputDir = 'en-US/generated';
/*
 * Selectors
 */

var getTranslationPackageRoot = function getTranslationPackageRoot() {
  return path.dirname(require.resolve("".concat(CATALOGS_ROOT, "/package.json")));
};

var getLocaleRoot = function getLocaleRoot() {
  return "".concat(getTranslationPackageRoot(), "/src/locale/");
};

var getDashRoot = function getDashRoot() {
  return path.dirname(require.resolve("".concat(dashPkgName, "/package.json")));
};

var getTranslationFilePaths = function getTranslationFilePaths() {
  var locale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'en-US';
  return glob.sync("".concat(getLocaleRoot()).concat(locale, "/*.json")).concat(glob.sync(path.join(getModuleCatalogsOutputPath(), '*.json')));
};

var getModuleCatalogsFilePaths = function getModuleCatalogsFilePaths() {
  return glob.sync("".concat(getDashRoot(), "/**/*.translations.ts"));
};

var getModuleCatalogNameFromPath = function getModuleCatalogNameFromPath(filePath) {
  return path.basename(filePath).replace('.translations.ts', '');
};

var getModuleCatalogsOutputPath = function getModuleCatalogsOutputPath() {
  return path.join(getTranslationPackageRoot(), "/src/locale/".concat(outputDir));
};
/**
 * getTranslationsMap
 * Maps the json translation files and return a Map that looks like
 * This function requires the files from the input paths and builds a map of
 * filesNames -> translations
 *
 *  Map {
 *    'access.json' => { hello: 'hello' },
 *    'worker.json' => { world: 'world' }
 *  }
 *
 * @return {Map} map - {<filename>:<translatoions>}
 */


var getTranslationsMap = function getTranslationsMap() {
  var locale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'en-US';
  var translations = new Map();
  getTranslationFilePaths(locale).forEach(function (filePath) {
    var translationFileName = path.basename(filePath),
        translationPhrases = require(filePath);

    translations.set(translationFileName, translationPhrases);
  });
  return translations;
};
/**
 * getCombinedTranslations
 *
 * Gets the final combined JSON object. Also does a check for duplicate translations
 * before building the object.
 *
 * @param {Map} map - {<key>: {<translations>}}
 * @return {Object} object- {<filename>:<translations>}
 */


var getCombinedTranslations = function getCombinedTranslations(translationsMap) {
  var duplicateTranslations = getDuplicateTranslations(translationsMap); // If we find a duplicate string, we cant recover so throw an error

  if (duplicateTranslations.length !== 0) {
    bail("Found duplicate translation key ".concat(JSON.stringify(duplicateTranslations), ". Canceling upload and exiting."));
  } // Convert the translations map to an object


  var translationsCombined = fromPairs(_toConsumableArray(translationsMap));
  return translationsCombined;
};
/**
 * getDuplicateTranslations
 * Gets duplicate transaltion keys in translation json files if any.
 *
 * This function returns an array of duplicte keys.
 * This array could be empty if no duplicates are found.
 *
 * Note: This function can only catch duplicates across different files.
 * It cannot detect duplicates in the same file.
 * It expects an input of a Map with the following structure
 *  Map {
 *    'access.json' => { hello: 'hello' },
 *    'worker.json' => { world: 'world' }
 *  }
 * @param {Map} map - {<key>: {<translations>}}
 * @return {Array} array- {[<duplicate keys>]}
 */


var getDuplicateTranslations = function getDuplicateTranslations(translationsMap) {
  var tmp = new Set(),
      duplicates = [];
  translationsMap.forEach(function (translations) {
    for (var key in translations) {
      if (tmp.has(key)) {
        duplicates.push(key);
      } else {
        tmp.add(key);
      }
    }
  });
  return duplicates;
};
/**
 * getModuleCatalogBuildScript
 * Gets the build script that we will write, run through webpack, and
 * then execute to generate regular json catalogs from module catalogs
 * @param {string[]} catalogPaths - Array of paths to to module catalogs
 * @return {string} The build script
 */


var getModuleCatalogBuildScript = function getModuleCatalogBuildScript() {
  var catalogPaths = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : getModuleCatalogsFilePaths();
  return "\n  require('babel-polyfill')\n\n  const fs = require('fs')\n  const util = require('util')\n  const path = require('path')\n  const mkdirp = util.promisify(require('mkdirp'))\n  const { bail, success, warn } = require('@cloudflare/cli-helpers').setup({\n    cliName: 'memsource-cli'\n  });;\n  const writeFileAsync = util.promisify(fs.writeFile)\n\n  const catalogs = {\n    ".concat(catalogPaths.map(function (p) {
    return [getModuleCatalogNameFromPath(p), p];
  }).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        name = _ref2[0],
        pathname = _ref2[1];

    return "\"".concat(name, "\": require(\"").concat(pathname, "\")");
  }).join(',\n'), "\n  }\n\n  Promise.all(Object.keys(catalogs).map(catalogName => {\n    const catalog = catalogs[catalogName]\n\n    return mkdirp(\"").concat(getModuleCatalogsOutputPath(), "\").then(() => writeFileAsync(\n      path.join(\"").concat(getModuleCatalogsOutputPath(), "\", catalogName) + '.json',\n      JSON.stringify(catalog.translations, null, '  ')\n    )).then(() => success('Module Catalog Generated: ' + catalogName)).catch(e => {\n      warn('Error writing: ' + catalogName)\n      warn(e)\n    })\n  }))\n  .then(() => process.exit(0))\n  .catch(e => bail(e))\n");
};
/**
 * buildModuleCatalogBuilder
 * Uses getModuleCatalogBuildScript to build a script which goes through
 * all `.translations.ts` files and produces an equivalent `catalog.json`
 * file, whose name corresponds to the prefix of the Module Catalog.
 * Since these Module Catalogs need to be run through webapck, we
 * generate a file which is run through webpack, and the resulting filename
 * is returned
 * @return {string} The output path of the build script
 */


var buildModuleCatalogBuilder =
/*#__PURE__*/
function () {
  var _ref3 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee() {
    var entry, filename, output;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            entry = path.join(__dirname, '../lib/build-module-catalogs.js');
            filename = 'output-module-catalogs-json.js';
            output = {
              filename: filename,
              path: path.join(__dirname, '../lib')
            };
            _context.next = 5;
            return mkdirp(path.join(__dirname, '../lib'));

          case 5:
            _context.next = 7;
            return writeFileAsync(entry, getModuleCatalogBuildScript());

          case 7:
            _context.next = 9;
            return new Promise(function (resolve, reject) {
              return require('webpack')(_objectSpread({}, require('./webpack.config'), {
                entry: entry,
                output: output
              }), function (error) {
                if (error) return reject(error);
                resolve();
              });
            });

          case 9:
            return _context.abrupt("return", path.join(__dirname, '../lib', filename));

          case 10:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function buildModuleCatalogBuilder() {
    return _ref3.apply(this, arguments);
  };
}(); // API utils


var authenticate = function authenticate() {
  return axios.post("".concat(baseUrl, "auth/login"), {
    userName: MEMSOURCE_USER,
    password: MEMSOURCE_PASS
  });
};
/**
 * writeFormattedJsonFile
 * Writes JSON file with indent:2 and detectIndent:true
 *
 * @param {string} filePath - file path
 * @param {content} - Contents to write
 * @return {Promise} promise- {Resolves if write success, else fails}
 */


var writeFormattedJsonFile = function writeFormattedJsonFile(filePath, content) {
  return writeJsonFile.sync(filePath, content, {
    indent: 2
  });
};
/**
 * getSplitTranslations
 * Splits combined translations into an array of arrays
 * For example
 *  {
 *    'access.json' : { hello: 'hello' },
 *    'worker.json' : { world: 'world' }
 *  }
 *  Becomes
 * [ [ 'access.json',{ hello: 'hello' } ],
 *   [ 'workers.json', { world: 'world' } ] ];
 *
 * @param {object} phrases - Object {<key>:{<translations>}}
 * @param {content} - Contents to write
 * @return {Promise} promise- {Resolves if write success, else fails}
 */


var getSplitTranslations = function getSplitTranslations(phrases) {
  return Object.entries(phrases);
};
/**
 * getNumOfLinks
 * Match the regex on the given markdown to count the
 * number of hyperlinks in it.
 *
 * @param {String} markdown
 * @return {Number} # of hyperlinks in given markdown
 */


var getNumOfLinks = function getNumOfLinks(markdown) {
  // match links in the format: [text here](link here)
  var checkLink = /\[(.*?)\]\((.*?)\)/g;
  return (markdown.match(checkLink) || []).length;
};
/**
 * getLocales
 * Gets a list of the available locales in the locale/ directory.
 *
 * @return {String[]} locales in the locale/ directory
 */


var getLocales = function getLocales() {
  var directories = readdirSync(getLocaleRoot()).filter(function (f) {
    return statSync(path.join(getLocaleRoot(), f)).isDirectory();
  });
  var outputDirIndex = directories.indexOf(outputDir); // we don't want to include the output directory

  if (outputDirIndex > -1) {
    directories.splice(outputDirIndex, 1);
  }

  return directories;
};

module.exports = {
  authenticate: authenticate,
  baseUrl: baseUrl,
  buildModuleCatalogBuilder: buildModuleCatalogBuilder,
  getCombinedTranslations: getCombinedTranslations,
  getDuplicateTranslations: getDuplicateTranslations,
  getModuleCatalogBuildScript: getModuleCatalogBuildScript,
  getModuleCatalogNameFromPath: getModuleCatalogNameFromPath,
  getModuleCatalogsFilePaths: getModuleCatalogsFilePaths,
  getSplitTranslations: getSplitTranslations,
  getTranslationFilePaths: getTranslationFilePaths,
  getTranslationPackageRoot: getTranslationPackageRoot,
  getTranslationsMap: getTranslationsMap,
  localeMap: localeMap,
  validStatus: validStatus,
  writeFormattedJsonFile: writeFormattedJsonFile,
  getNumOfLinks: getNumOfLinks,
  getLocales: getLocales
};

==> memsource-cli-3.5.53.tgz: package/lib/utils.js <==
"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var fs = require('fs');

var axios = require('axios');

var findConfig = require('find-config');

var path = require('path');

var glob = require('glob');

var util = require('util');

var writeJsonFile = require('write-json-file');

var fromPairs = require('lodash.frompairs');

var writeFileAsync = util.promisify(fs.writeFile);
var mkdirp = util.promisify(require('mkdirp'));

var _require$setup = require('@cloudflare/cli-helpers').setup({
  cliName: 'memsource-cli'
}),
    bail = _require$setup.bail;

var config = findConfig.require('memsource.config.js');

var MEMSOURCE_USER = config.MEMSOURCE_USER,
    MEMSOURCE_PASS = config.MEMSOURCE_PASS;
var readdirSync = fs.readdirSync,
    statSync = fs.statSync;
/*
 * Constants
 */

var baseUrl = 'https://cloud.memsource.com/web/api2/v1/';
var dashPkgName = '@cloudflare/app-dash';
var CATALOGS_ROOT = '@cloudflare/intl-translations';
var validStatus = 'DELIVERED';
var localeMap = {
  de_de: 'de-DE'
};
var outputDir = 'en-US/generated';
/*
 * Selectors
 */

var getTranslationPackageRoot = function getTranslationPackageRoot() {
  return path.dirname(require.resolve("".concat(CATALOGS_ROOT, "/package.json")));
};

var getLocaleRoot = function getLocaleRoot() {
  return "".concat(getTranslationPackageRoot(), "/src/locale/");
};

var getDashRoot = function getDashRoot() {
  return path.dirname(require.resolve("".concat(dashPkgName, "/package.json")));
};

var getTranslationFilePaths = function getTranslationFilePaths() {
  var locale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'en-US';
  return glob.sync("".concat(getLocaleRoot()).concat(locale, "/*.json")).concat(glob.sync(path.join(getModuleCatalogsOutputPath(), '*.json')));
};

var getModuleCatalogsFilePaths = function getModuleCatalogsFilePaths() {
  return glob.sync("".concat(getDashRoot(), "/**/*.translations.ts"));
};

var getModuleCatalogNameFromPath = function getModuleCatalogNameFromPath(filePath) {
  return path.basename(filePath).replace('.translations.ts', '');
};

var getModuleCatalogsOutputPath = function getModuleCatalogsOutputPath() {
  return path.join(getTranslationPackageRoot(), "/src/locale/".concat(outputDir));
};
/**
 * getTranslationsMap
 * Maps the json translation files and return a Map that looks like
 * This function requires the files from the input paths and builds a map of
 * filesNames -> translations
 *
 *  Map {
 *    'access.json' => { hello: 'hello' },
 *    'worker.json' => { world: 'world' }
 *  }
 *
 * @return {Map} map - {<filename>:<translatoions>}
 */


var getTranslationsMap = function getTranslationsMap() {
  var locale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'en-US';
  var translations = new Map();
  getTranslationFilePaths(locale).forEach(function (filePath) {
    var translationFileName = path.basename(filePath),
        translationPhrases = require(filePath);

    translations.set(translationFileName, translationPhrases);
  });
  return translations;
};
/**
 * getCombinedTranslations
 *
 * Gets the final combined JSON object. Also does a check for duplicate translations
 * before building the object.
 *
 * @param {Map} map - {<key>: {<translations>}}
 * @return {Object} object- {<filename>:<translations>}
 */


var getCombinedTranslations = function getCombinedTranslations(translationsMap) {
  var duplicateTranslations = getDuplicateTranslations(translationsMap); // If we find a duplicate string, we cant recover so throw an error

  if (duplicateTranslations.length !== 0) {
    bail("Found duplicate translation key ".concat(JSON.stringify(duplicateTranslations), ". Canceling upload and exiting."));
  } // Convert the translations map to an object


  var translationsCombined = fromPairs(_toConsumableArray(translationsMap));
  return translationsCombined;
};
/**
 * getDuplicateTranslations
 * Gets duplicate transaltion keys in translation json files if any.
 *
 * This function returns an array of duplicte keys.
 * This array could be empty if no duplicates are found.
 *
 * Note: This function can only catch duplicates across different files.
 * It cannot detect duplicates in the same file.
 * It expects an input of a Map with the following structure
 *  Map {
 *    'access.json' => { hello: 'hello' },
 *    'worker.json' => { world: 'world' }
 *  }
 * @param {Map} map - {<key>: {<translations>}}
 * @return {Array} array- {[<duplicate keys>]}
 */


var getDuplicateTranslations = function getDuplicateTranslations(translationsMap) {
  var tmp = new Set(),
      duplicates = [];
  translationsMap.forEach(function (translations) {
    for (var key in translations) {
      if (tmp.has(key)) {
        duplicates.push(key);
      } else {
        tmp.add(key);
      }
    }
  });
  return duplicates;
};
/**
 * getModuleCatalogBuildScript
 * Gets the build script that we will write, run through webpack, and
 * then execute to generate regular json catalogs from module catalogs
 * @param {string[]} catalogPaths - Array of paths to to module catalogs
 * @return {string} The build script
 */


var getModuleCatalogBuildScript = function getModuleCatalogBuildScript() {
  var catalogPaths = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : getModuleCatalogsFilePaths();
  return "\n  require('babel-polyfill')\n\n  const fs = require('fs')\n  const util = require('util')\n  const path = require('path')\n  const mkdirp = util.promisify(require('mkdirp'))\n  const { bail, success, warn } = require('@cloudflare/cli-helpers').setup({\n    cliName: 'memsource-cli'\n  });;\n  const writeFileAsync = util.promisify(fs.writeFile)\n\n  const catalogs = {\n    ".concat(catalogPaths.map(function (p) {
    return [getModuleCatalogNameFromPath(p), p];
  }).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        name = _ref2[0],
        pathname = _ref2[1];

    return "\"".concat(name, "\": require(\"").concat(pathname, "\")");
  }).join(',\n'), "\n  }\n\n  Promise.all(Object.keys(catalogs).map(catalogName => {\n    const catalog = catalogs[catalogName]\n\n    return mkdirp(\"").concat(getModuleCatalogsOutputPath(), "\").then(() => writeFileAsync(\n      path.join(\"").concat(getModuleCatalogsOutputPath(), "\", catalogName) + '.json',\n      JSON.stringify(catalog.translations, null, '  ')\n    )).then(() => success('Module Catalog Generated: ' + catalogName)).catch(e => {\n      warn('Error writing: ' + catalogName)\n      warn(e)\n    })\n  }))\n  .then(() => process.exit(0))\n  .catch(e => bail(e))\n");
};
/**
 * buildModuleCatalogBuilder
 * Uses getModuleCatalogBuildScript to build a script which goes through
 * all `.translations.ts` files and produces an equivalent `catalog.json`
 * file, whose name corresponds to the prefix of the Module Catalog.
 * Since these Module Catalogs need to be run through webapck, we
 * generate a file which is run through webpack, and the resulting filename
 * is returned
 * @return {string} The output path of the build script
 */


var buildModuleCatalogBuilder = /*#__PURE__*/function () {
  var _ref3 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
    var entry, filename, output;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            entry = path.join(__dirname, '../lib/build-module-catalogs.js');
            filename = 'output-module-catalogs-json.js';
            output = {
              filename: filename,
              path: path.join(__dirname, '../lib')
            };
            _context.next = 5;
            return mkdirp(path.join(__dirname, '../lib'));

          case 5:
            _context.next = 7;
            return writeFileAsync(entry, getModuleCatalogBuildScript());

          case 7:
            _context.next = 9;
            return new Promise(function (resolve, reject) {
              return require('webpack')(_objectSpread({}, require('./webpack.config'), {
                entry: entry,
                output: output
              }), function (error) {
                if (error) return reject(error);
                resolve();
              });
            });

          case 9:
            return _context.abrupt("return", path.join(__dirname, '../lib', filename));

          case 10:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function buildModuleCatalogBuilder() {
    return _ref3.apply(this, arguments);
  };
}(); // API utils


var authenticate = function authenticate() {
  return axios.post("".concat(baseUrl, "auth/login"), {
    userName: MEMSOURCE_USER,
    password: MEMSOURCE_PASS
  });
};
/**
 * writeFormattedJsonFile
 * Writes JSON file with indent:2 and detectIndent:true
 *
 * @param {string} filePath - file path
 * @param {content} - Contents to write
 * @return {Promise} promise- {Resolves if write success, else fails}
 */


var writeFormattedJsonFile = function writeFormattedJsonFile(filePath, content) {
  return writeJsonFile.sync(filePath, content, {
    indent: 2
  });
};
/**
 * getSplitTranslations
 * Splits combined translations into an array of arrays
 * For example
 *  {
 *    'access.json' : { hello: 'hello' },
 *    'worker.json' : { world: 'world' }
 *  }
 *  Becomes
 * [ [ 'access.json',{ hello: 'hello' } ],
 *   [ 'workers.json', { world: 'world' } ] ];
 *
 * @param {object} phrases - Object {<key>:{<translations>}}
 * @param {content} - Contents to write
 * @return {Promise} promise- {Resolves if write success, else fails}
 */


var getSplitTranslations = function getSplitTranslations(phrases) {
  return Object.entries(phrases);
};
/**
 * getNumOfLinks
 * Match the regex on the given markdown to count the
 * number of hyperlinks in it.
 *
 * @param {String} markdown
 * @return {Number} # of hyperlinks in given markdown
 */


var getNumOfLinks = function getNumOfLinks(markdown) {
  // match links in the format: [text here](link here)
  var checkLink = /\[(.*?)\]\((.*?)\)/g;
  return (markdown.match(checkLink) || []).length;
};
/**
 * getLocales
 * Gets a list of the available locales in the locale/ directory.
 *
 * @return {String[]} locales in the locale/ directory
 */


var getLocales = function getLocales() {
  var directories = readdirSync(getLocaleRoot()).filter(function (f) {
    return statSync(path.join(getLocaleRoot(), f)).isDirectory();
  });
  var outputDirIndex = directories.indexOf(outputDir); // we don't want to include the output directory

  if (outputDirIndex > -1) {
    directories.splice(outputDirIndex, 1);
  }

  return directories;
};

module.exports = {
  authenticate: authenticate,
  baseUrl: baseUrl,
  buildModuleCatalogBuilder: buildModuleCatalogBuilder,
  getCombinedTranslations: getCombinedTranslations,
  getDuplicateTranslations: getDuplicateTranslations,
  getModuleCatalogBuildScript: getModuleCatalogBuildScript,
  getModuleCatalogNameFromPath: getModuleCatalogNameFromPath,
  getModuleCatalogsFilePaths: getModuleCatalogsFilePaths,
  getSplitTranslations: getSplitTranslations,
  getTranslationFilePaths: getTranslationFilePaths,
  getTranslationPackageRoot: getTranslationPackageRoot,
  getTranslationsMap: getTranslationsMap,
  localeMap: localeMap,
  validStatus: validStatus,
  writeFormattedJsonFile: writeFormattedJsonFile,
  getNumOfLinks: getNumOfLinks,
  getLocales: getLocales
};
